<template>
	<div :style='widgetWrapperStyle'>
		<div class='voting' :style='{...widgetStyle, ...transitionStyle}'>
			<div class='title' v-text="question"/>
			<div class='answer' @click='setAnswer(1)' v-text="answer1" v-if="answer1" :class="classValue(1)"/>
			<div class='answer' @click='setAnswer(2)' v-text="answer2" v-if="answer2" :class="classValue(2)"/>
			<div class='answer' @click='setAnswer(3)' v-text="answer3" v-if="answer3" :class="classValue(3)"/>
		</div>
	</div>
</template>

<script>
import {widgetMixin, positionMixin} from '../helpers/widgets.mjs'

export default {
	mixins: [widgetMixin, positionMixin],

	props: {
		question: {
			type: String,
			default: '',
		},
		answer1: {
			type: String,
			default: '',
		},
		answer2: {
			type: String,
			default: '',
		},
		answer3: {
			type: String,
			default: '',
		},
		time: {
			type: Number,
			default: 0,
		},

		correctAnswer: {
			default: 1,
		},
	},

	data() {
		return {
			selectedAnswer: 0,
		}
	},

	watch: {
		time(value) {
			const phase = (value - this.contentItem.start) / this.contentItem.duration

			if (phase > 2 / 3) this.setAnswer(-1)
		},
	},

	methods: {
		setAnswer(value) {
			if (this.selectedAnswer) return

			this.selectedAnswer = value
		},

		classValue(value) {
			const result = []

			if (this.selectedAnswer) {
				result.push('disabled')
				if (parseInt(this.correctAnswer) === value) {
					result.push('green')
				}

				if (this.selectedAnswer === value && this.selectedAnswer !== parseInt(this.correctAnswer)) {
					result.push('red')
				}
			}

			return result.join(' ')
		},
	},
}
</script>

<style scoped>
.voting {
	color: #FFFFFF;
    font-variation-settings: 'wght' 350;
	line-height: 112%;
	background: rgba(0, 0, 0, 0.15);
	backdrop-filter: blur(20px);
	border-radius: .5em;
	padding: 1em;
	display: flex;
	flex-direction: column;
	pointer-events: all;
	max-width: 15em;
	min-width: 10em;
	font-family: var(--primary-font);
    gap: .6em;
}

.title {
    margin-bottom: .3em;
}

.voting .answer {
	height: 2.7em;
    font-size: .8em;

	display: flex;
	align-items: center;
	pointer-events: all;
	cursor: pointer;
	background: rgba(255, 255, 255, 0.25);
	border-radius: 1.2em;
	padding: 0 1.6em;
	transition: background .2s ease, color .2s ease;

    font-variation-settings: 'wght' 500;
}

.answer:hover {
    background: rgba(255, 255, 255, 0.35);
}

.answer.red {
    background: rgba(255, 100, 100);
}

.answer.green {
    background: #48FF7B;
	color: black;
}

.answer.disabled {
    cursor: default
}

</style>
